@@ -47,11 +47,7 @@
 #include <QList>
 #include <QTextStream>
 #include <QEventLoop>
-
-#include <kapplication.h>
-#include <kdebug.h>
-#include <kgenericfactory.h>
-#include <klocale.h>
+#include <QDebug>
 
 #include "catalogitem.h"
 
@@ -62,26 +58,32 @@ using namespace GettextCatalog;
 //    , _extraDataSaver(extraDataSaver)
 GettextImportPlugin::GettextImportPlugin()
    : CatalogImportPlugin()
-   , _rxMsgCtxt          ("^msgctxt\\s*\".*\"$")
-   , _rxMsgId            ("^msgid\\s*\".*\"$")
-   , _rxMsgIdPlural      ("^msgid_plural\\s*\".*\"$")
-   , _rxMsgIdPluralBorked("^msgid_plural\\s*\"?.*\"?$")
-   , _rxMsgIdBorked      ("^msgid\\s*\"?.*\"?$")
-   , _rxMsgIdRemQuotes   ("^msgid\\s*\"")
-   , _rxMsgLineRemEndQuote      ("\"$")
-   , _rxMsgLineRemStartQuote    ("^\"")
-   , _rxMsgLine          ("^\".*\\n?\"$")
-   , _rxMsgLineBorked    ("^\"?.+\\n?\"?$")
-   , _rxMsgStr           ("^msgstr\\s*\".*\\n?\"$")
-   , _rxMsgStrOther      ("^msgstr\\s*\"?.*\\n?\"?$")
-   , _rxMsgStrPluralStart("^msgstr\\[0\\]\\s*\".*\\n?\"$")
-   , _rxMsgStrPluralStartBorked ("^msgstr\\[0\\]\\s*\"?.*\\n?\"?$")
-   , _rxMsgStrPlural     ("^msgstr\\[[0-9]+\\]\\s*\".*\\n?\"$")
-   , _rxMsgStrPluralBorked      ("^msgstr\\[[0-9]\\]\\s*\"?.*\\n?\"?$")
-   , _rxMsgStrRemQuotes  ("^msgstr\\s*\"?")
-//    , _rxMsgId   ("^msgid\\s*\"?.*\"?$")
-   , _obsoleteStart("#~")
-   , _msgctxtStart("msgctxt")
+   , _msgidMultiline(false)
+   , _msgstrMultiline(false)
+   , _gettextPluralForm(false)
+   , _testBorked(false)
+   , _obsolete(false)
+   , _msgctxtPresent(false)
+   , _rxMsgCtxt          (QStringLiteral("^msgctxt\\s*\".*\"$"))
+   , _rxMsgId            (QStringLiteral("^msgid\\s*\".*\"$"))
+   , _rxMsgIdPlural      (QStringLiteral("^msgid_plural\\s*\".*\"$"))
+   , _rxMsgIdPluralBorked(QStringLiteral("^msgid_plural\\s*\"?.*\"?$"))
+   , _rxMsgIdBorked      (QStringLiteral("^msgid\\s*\"?.*\"?$"))
+   , _rxMsgIdRemQuotes   (QStringLiteral("^msgid\\s*\""))
+   , _rxMsgLineRemEndQuote      (QStringLiteral("\"$"))
+   , _rxMsgLineRemStartQuote    (QStringLiteral("^\""))
+   , _rxMsgLine          (QStringLiteral("^\".*\\n?\"$"))
+   , _rxMsgLineBorked    (QStringLiteral("^\"?.+\\n?\"?$"))
+   , _rxMsgStr           (QStringLiteral("^msgstr\\s*\".*\\n?\"$"))
+   , _rxMsgStrOther      (QStringLiteral("^msgstr\\s*\"?.*\\n?\"?$"))
+   , _rxMsgStrPluralStart(QStringLiteral("^msgstr\\[0\\]\\s*\".*\\n?\"$"))
+   , _rxMsgStrPluralStartBorked (QStringLiteral("^msgstr\\[0\\]\\s*\"?.*\\n?\"?$"))
+   , _rxMsgStrPlural     (QStringLiteral("^msgstr\\[[0-9]+\\]\\s*\".*\\n?\"$"))
+   , _rxMsgStrPluralBorked      (QStringLiteral("^msgstr\\[[0-9]\\]\\s*\"?.*\\n?\"?$"))
+   , _rxMsgStrRemQuotes  (QStringLiteral("^msgstr\\s*\"?"))
+//    , _rxMsgId   (QStringLiteral("^msgid\\s*\"?.*\"?$"))
+   , _obsoleteStart(QStringLiteral("#~"))
+   , _msgctxtStart(QStringLiteral("msgctxt"))
 
 {
 }
@@ -104,7 +106,7 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
    // if somethings goes wrong with the parsing, we don't have deleted the old contents
    CatalogItem tempHeader;
 
-   kDebug() << "start parsing...";
+   qDebug() << "start parsing...";
    QTime aaa;
    aaa.start();
    // first read header
@@ -113,22 +115,22 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
    bool recoveredErrorInHeader = false;
    if (KDE_ISUNLIKELY( status == RECOVERED_PARSE_ERROR ))
    {
-      kDebug() << "Recovered error in header entry";
+      qDebug() << "Recovered error in header entry";
       recoveredErrorInHeader = true;
    }
    else if (KDE_ISUNLIKELY( status != OK ))
    {
-      kWarning() << "Parse error in header entry";
+      qWarning() << "Parse error in header entry";
       return status;
    }
 
    bool reconstructedHeader=!_msgid.isEmpty() && !_msgid.first().isEmpty();
-   //kWarning() << "HEADER MSGID: " << _msgid;
-   //kWarning() << "HEADER MSGSTR: " << _msgstr;
+   //qWarning() << "HEADER MSGID: " << _msgid;
+   //qWarning() << "HEADER MSGSTR: " << _msgstr;
    if (KDE_ISUNLIKELY( reconstructedHeader ))
    {
       // The header must have an empty msgid
-      kWarning() << "Header entry has non-empty msgid. Creating a temporary header! " << _msgid;
+      qWarning() << "Header entry has non-empty msgid. Creating a temporary header! " << _msgid;
       tempHeader.setMsgid( QString() );
       QString tmp(
          "Content-Type: text/plain; charset=UTF-8\\n" // Unknown charset
@@ -163,7 +165,7 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
    // now parse the rest of the file
    uint counter=0;
    QList<int> errorIndex;
-   bool recoveredError=false;
+   //bool recoveredError=false;
    bool docbookFile=false;
 
    ExtraDataSaver _extraDataSaver;
@@ -197,8 +199,8 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
       }
       else if(KDE_ISUNLIKELY( success==RECOVERED_PARSE_ERROR ))
       {
-         kDebug() << "Recovered parse error in entry: " << counter;
-         recoveredError=true;
+         qDebug() << "Recovered parse error in entry: " << counter;
+         //recoveredError=true;
          errorIndex.append(counter);
 
             CatalogItem tempCatItem;
@@ -214,12 +216,12 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
       }
       else if (success == PARSE_ERROR)
       {
-         kDebug() << "Parse error in entry: " << counter;
+         qDebug() << "Parse error in entry: " << counter;
          return PARSE_ERROR;
       }
       else
       {
-         kDebug() << "Unknown success status, assumig parse error " << success;
+         qDebug() << "Unknown success status, assumig parse error " << success;
          return PARSE_ERROR;
       }
       counter++;
@@ -230,11 +232,11 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
    if (KDE_ISUNLIKELY( !counter && !recoveredErrorInHeader ))
    {
       // Empty file? (Otherwise, there would be a try of getting an entry and the count would be 1 !)
-      kDebug() << " Empty file?";
+      qDebug() << " Empty file?";
       return PARSE_ERROR;
    }
 
-   kDebug() << " ready";
+   qDebug() << " ready";
 
    // We have successfully loaded the file (perhaps with recovered errors)
 
@@ -249,18 +251,18 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
 #if 0
    if (KDE_ISUNLIKELY( recoveredErrorInHeader ))
    {
-      kDebug() << " Returning: header error";
+      qDebug() << " Returning: header error";
       return RECOVERED_HEADER_ERROR;
    }
    else if (KDE_ISUNLIKELY( recoveredError ))
    {
-      kDebug() << " Returning: recovered parse error";
+      qDebug() << " Returning: recovered parse error";
       return RECOVERED_PARSE_ERROR;
    }
    else
 #endif
    {
-      kDebug() << " Returning: OK! :-)";
+      qDebug() << " Returning: OK! :-)";
       return OK;
    }
 }
@@ -277,32 +279,32 @@ QTextCodec* GettextImportPlugin::codecForDevice(QIODevice* device/*, bool* hadCo
     ConversionStatus status = readEntry(stream);
     if (KDE_ISUNLIKELY( status!=OK && status != RECOVERED_PARSE_ERROR ))
     {
-        kDebug() << "wasn't able to read header";
+        qDebug() << "wasn't able to read header";
         return codec;
     }
 
-    QRegExp regexp("Content-Type:\\s*\\w+/[-\\w]+;?\\s*charset\\s*=\\s*(\\S+)\\s*\\\\n");
+    QRegExp regexp(QStringLiteral("Content-Type:\\s*\\w+/[-\\w]+;?\\s*charset\\s*=\\s*(\\S+)\\s*\\\\n"));
     if ( regexp.indexIn( _msgstr.first() ) == -1 )
     {
-        kDebug() << "no charset entry found";
+        qDebug() << "no charset entry found";
         return codec;
     }
 
     const QString charset = regexp.cap(1);
-    kDebug() << "charset: " << charset;
+    qDebug() << "charset: " << charset;
 
     if (charset.isEmpty())
     {
-        kWarning() << "No charset defined! Assuming UTF-8!";
+        qWarning() << "No charset defined! Assuming UTF-8!";
         return codec;
     }
 
     // "CHARSET" is the default charset entry in a template (pot).
     // characters in a template should be either pure ascii or
     // at least utf8, so utf8-codec can be used for both.
-    if ( charset.contains("CHARSET"))
+    if ( charset.contains(QLatin1String("CHARSET")))
     {
-        kDebug() << QString("file seems to be a template: using utf-8 encoding.");
+        qDebug() << QString("file seems to be a template: using utf-8 encoding.");
         return QTextCodec::codecForName("utf8");;
     }
 
@@ -312,7 +314,7 @@ QTextCodec* GettextImportPlugin::codecForDevice(QIODevice* device/*, bool* hadCo
     if (t)
         return t;
     else
-       kWarning() << "charset found, but no codec available, using UTF-8 instead";
+       qWarning() << "charset found, but no codec available, using UTF-8 instead";
 
     return codec;//UTF-8
 }
@@ -320,21 +322,21 @@ QTextCodec* GettextImportPlugin::codecForDevice(QIODevice* device/*, bool* hadCo
 ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
 {
    ConversionStatus result=readEntryRaw(stream);
-   _msgstr.replaceInStrings("\\\"","\"");
-   _msgid.replaceInStrings("\\\"","\"");
-   _msgctxt.replace("\\\"","\"");
+   _msgstr.replaceInStrings(QStringLiteral("\\\""),QStringLiteral("\""));
+   _msgid.replaceInStrings(QStringLiteral("\\\""),QStringLiteral("\""));
+   _msgctxt.replace(QStringLiteral("\\\""),QStringLiteral("\""));
    return result;
 }
 
 ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
 {
-   //kDebug() << " START";
+   //qDebug() << " START";
    enum {Begin,Comment,Msgctxt,Msgid,Msgstr} part=Begin;
 
    _trailingNewLines=0;
    bool error=false;
    bool recoverableError=false;
-   bool seenMsgctxt=false;
+   //bool seenMsgctxt=false;
    _msgstr.clear();
    _msgstr.append(QString());
    _msgid.clear();
@@ -360,16 +362,14 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
        else
            line=stream.readLine();
 
-       kDebug() << "Parsing line: " << line;
-
-       static const QString lesslessless="<<<<<<<";
-       static const QString isisis="=======";
-       static const QString moremoremore=">>>>>>>";
+       static const QString lesslessless=QStringLiteral("<<<<<<<");
+       static const QString isisis=QStringLiteral("=======");
+       static const QString moremoremore=QStringLiteral(">>>>>>>");
        if (KDE_ISUNLIKELY( line.startsWith( lesslessless ) || line.startsWith( isisis ) || line.startsWith( moremoremore ) ))
        {
           // We have found a CVS/SVN conflict marker. Abort.
           // (It cannot be any useful data of the PO file, as otherwise the line would start with at least a quote)
-          kError() << "CVS/SVN conflict marker found! Aborting!" << endl << line << endl;
+          qWarning() << "CVS/SVN conflict marker found! Aborting!" << endl << line << endl;
           return PARSE_ERROR;
        }
 
@@ -410,11 +410,11 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                part=Msgctxt;
 
                // remove quotes at beginning and the end of the lines
-               line.remove(QRegExp("^msgctxt\\s*\""));
+               line.remove(QRegExp(QStringLiteral("^msgctxt\\s*\"")));
                line.remove(_rxMsgLineRemEndQuote);
                _msgctxt=line;
                _msgctxtPresent=true;
-               seenMsgctxt=true;
+               //seenMsgctxt=true;
            }
            else if( line.contains( _rxMsgId ) )
            {
@@ -434,7 +434,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                part=Msgid;
 
                // remove quotes at beginning and the end of the lines
-               line.remove(QRegExp("^msgid\\s*\"?"));
+               line.remove(QRegExp(QStringLiteral("^msgid\\s*\"?")));
                line.remove(_rxMsgLineRemEndQuote);
 
                _msgidMultiline=line.isEmpty();
@@ -445,7 +445,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
            }
            else
            {
-               kDebug() << "no comment, msgctxt or msgid found after a comment: " << line;
+               qDebug() << "no comment, msgctxt or msgid found after a comment: " << line;
                error=true;
                break;
            }
@@ -468,11 +468,11 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                part=Msgctxt;
 
                // remove quotes at beginning and the end of the lines
-               line.remove(QRegExp("^msgctxt\\s*\""));
+               line.remove(QRegExp(QStringLiteral("^msgctxt\\s*\"")));
                line.remove(_rxMsgLineRemEndQuote);
                _msgctxt=line;
                _msgctxtPresent=true;
-               seenMsgctxt=true;
+               //seenMsgctxt=true;
             }
             else if( line.contains( _rxMsgId ) )
             {
@@ -502,7 +502,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
             }
             else
             {
-               kDebug() << "no comment or msgid found after a comment while parsing: " << _comment;
+               qDebug() << "no comment or msgid found after a comment while parsing: " << _comment;
                error=true;
                break;
             }
@@ -541,7 +541,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                part=Msgid;
 
                // remove quotes at beginning and the end of the lines
-               line.remove(QRegExp("^msgid\\s*\"?"));
+               line.remove(QRegExp(QStringLiteral("^msgid\\s*\"?")));
                line.remove(_rxMsgLineRemEndQuote);
 
                _msgidMultiline=line.isEmpty();
@@ -552,7 +552,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
             }
             else
             {
-               kDebug() << "no msgid found after a msgctxt while parsing: " << _msgctxt;
+               qDebug() << "no msgid found after a msgctxt while parsing: " << _msgctxt;
                error=true;
                break;
             }
@@ -588,7 +588,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                _gettextPluralForm = true;
 
                // remove quotes at beginning and the end of the lines
-               line.remove(QRegExp("^msgid_plural\\s*\""));
+               line.remove(QRegExp(QStringLiteral("^msgid_plural\\s*\"")));
                line.remove(_rxMsgLineRemEndQuote);
 
                _msgid.append(line);
@@ -600,7 +600,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                _gettextPluralForm = true;
 
                // remove quotes at beginning and the end of the lines
-               line.remove(QRegExp("^msgid_plural\\s*\"?"));
+               line.remove(QRegExp(QStringLiteral("^msgid_plural\\s*\"?")));
                line.remove(_rxMsgLineRemEndQuote);
 
                _msgid.append(line);
@@ -638,7 +638,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                part=Msgstr;
 
                // remove quotes at beginning and the end of the lines
-               line.remove(QRegExp("^msgstr\\[0\\]\\s*\"?"));
+               line.remove(QRegExp(QStringLiteral("^msgstr\\[0\\]\\s*\"?")));
                line.remove(_rxMsgLineRemEndQuote);
 
                _msgstrMultiline=line.isEmpty();
@@ -649,7 +649,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                part=Msgstr;
 
                // remove quotes at beginning and the end of the lines
-               line.remove(QRegExp("^msgstr\\[0\\]\\s*\"?"));
+               line.remove(QRegExp(QStringLiteral("^msgstr\\[0\\]\\s*\"?")));
                line.remove(_rxMsgLineRemEndQuote);
 
                _msgstrMultiline=line.isEmpty();
@@ -661,13 +661,13 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
             else if ( line.startsWith( '#' ) )
             {
                // ### TODO: could this be considered recoverable?
-               kDebug() << "comment found after a msgid while parsing: " << _msgid.first();
+               qDebug() << "comment found after a msgid while parsing: " << _msgid.first();
                error=true;
                break;
             }
-            else if ( line.startsWith( "msgid" ) )
+            else if ( line.startsWith( QStringLiteral("msgid") ) )
             {
-               kDebug() << "Another msgid found after a msgid while parsing: " << _msgid.first();
+               qDebug() << "Another msgid found after a msgid while parsing: " << _msgid.first();
                error=true;
                break;
             }
@@ -697,7 +697,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
             }
             else
             {
-               kDebug() << "no msgstr found after a msgid while parsing: " << _msgid.first();
+               qDebug() << "no msgstr found after a msgid while parsing: " << _msgid.first();
                error=true;
                break;
             }
@@ -720,14 +720,14 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
             else if( _gettextPluralForm && ( line.contains( _rxMsgStrPlural ) ) )
             {
                // remove quotes at beginning and the end of the lines
-               line.remove(QRegExp("^msgstr\\[[0-9]+\\]\\s*\"?"));
+               line.remove(QRegExp(QStringLiteral("^msgstr\\[[0-9]+\\]\\s*\"?")));
                line.remove(_rxMsgLineRemEndQuote);
 
                _msgstr.append(line);
                msgstrIt=_msgstr.end();
                --msgstrIt;
             }
-            else if ( line.startsWith( '#' ) || line.startsWith( "msgid" ) )
+            else if ( line.startsWith( '#' ) || line.startsWith( QStringLiteral("msgid") ) )
             {
                _errorLine--;
                _bufferedLine=line;
@@ -736,7 +736,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
             else if(KDE_ISUNLIKELY(/*_testBorked&&*/ _gettextPluralForm && ( line.contains( _rxMsgStrPluralBorked ) ) ))
             {
                // remove quotes at beginning and the end of the lines
-               line.remove(QRegExp("^msgstr\\[[0-9]\\]\\s*\"?"));
+               line.remove(QRegExp(QStringLiteral("^msgstr\\[[0-9]\\]\\s*\"?")));
                line.remove(_rxMsgLineRemEndQuote);
 
                _msgstr.append(line);
@@ -746,9 +746,9 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                if(!line.isEmpty())
                   recoverableError=true;
             }
-            else if(line.startsWith("msgstr"))
+            else if(line.startsWith(QLatin1String("msgstr")))
             {
-               kDebug() << "Another msgstr found after a msgstr while parsing: " << line << _msgstr.last();
+               qDebug() << "Another msgstr found after a msgstr while parsing: " << line << _msgstr.last();
                error=true;
                break;
             }
@@ -767,7 +767,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
             }
             else
             {
-               kDebug() << "no msgid or comment found after a msgstr while parsing: " << _msgstr.last();
+               qDebug() << "no msgid or comment found after a msgstr while parsing: " << _msgstr.last();
                error=true;
                break;
             }
@@ -777,20 +777,20 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
 /*
    if(_gettextPluralForm)
    {
-       kDebug() << "gettext plural form:\n"
+       qDebug() << "gettext plural form:\n"
                  << "msgid:\n" << _msgid.first() << "\n"
                  << "msgid_plural:\n" << _msgid.last() << "\n" << endl;
        int counter=0;
        for(QStringList::Iterator it = _msgstr.begin(); it != _msgstr.end(); ++it)
        {
-           kDebug() << "msgstr[" << counter << "]:\n" 
+           qDebug() << "msgstr[" << counter << "]:\n" 
                      << (*it) << endl;
            counter++;
        }
    }
   */
 
-    //kDebug() << " NEAR RETURN";
+    //qDebug() << " NEAR RETURN";
     if(KDE_ISUNLIKELY(error))
         return PARSE_ERROR;
     else if(KDE_ISUNLIKELY(recoverableError))
